@@ -1,32 +1,36 @@
-#include "RcppArmadillo.h"
+#include <RcppArmadillo.h>
 #include "leapandshift.h"
 #include "distances.h"
 #include "partitionfuns.h"
-#include <cmath>
 
+using namespace arma;
 
 // [[Rcpp::depends(RcppArmadillo)]]
 
 // Initialize latent ranks as provided by rho_init, or randomly:
-arma::mat initialize_rho(Rcpp::Nullable<arma::mat> rho_init, int n_items, int n_clusters){
+arma::mat initialize_rho(int n_items, int n_cols, Rcpp::Nullable<arma::mat> rho_init){
   if(rho_init.isNotNull()){
-    return arma::repmat(Rcpp::as<arma::mat>(rho_init), 1, n_clusters);
+    return repmat(Rcpp::as<mat>(rho_init), 1, n_cols);
   } else {
-    return arma::shuffle(arma::repmat(arma::regspace<arma::mat>(1, 1, n_items), 1, n_clusters));
+    mat rho_samples(n_items, n_cols);
+    for (uword i = 0; i < n_cols; ++i) {
+      rho_samples.col(i) = randperm<vec>(n_items) + 1;
+    }
+    return rho_samples;
   }
 }
 
-double update_alpha(arma::vec& alpha_acceptance,
+double update_alpha(vec& alpha_acceptance,
                   const double& alpha_old,
-                  const arma::mat& rankings,
-                  const arma::vec& obs_freq,
+                  const mat& rankings,
+                  const vec& obs_freq,
                   const int& cluster_index,
-                  const arma::vec& rho_old,
+                  const vec& rho_old,
                   const double& alpha_prop_sd,
                   const std::string& metric,
                   const double& lambda,
-                  const Rcpp::Nullable<arma::vec> cardinalities = R_NilValue,
-                  const Rcpp::Nullable<arma::vec> logz_estimate = R_NilValue,
+                  const Rcpp::Nullable<vec> cardinalities = R_NilValue,
+                  const Rcpp::Nullable<vec> logz_estimate = R_NilValue,
                   double alpha_max = 1e6) {
 
 
@@ -35,12 +39,11 @@ double update_alpha(arma::vec& alpha_acceptance,
   //int n_assessors = rankings.n_cols;
   int n_items = rho_old.n_elem;
 
-  double alpha_proposal = std::exp(arma::randn<double>() * alpha_prop_sd +
+  double alpha_proposal = std::exp(randn<double>() * alpha_prop_sd +
                               std::log(alpha_old));
 
   double rank_dist = rank_dist_sum(rankings, rho_old, metric, obs_freq);
 
-
   // Difference between current and proposed alpha
   double alpha_diff = alpha_old - alpha_proposal;
 
@@ -48,13 +51,13 @@ double update_alpha(arma::vec& alpha_acceptance,
   double ratio =
     alpha_diff / n_items * rank_dist +
     lambda * alpha_diff +
-    arma::sum(obs_freq) * (
+    sum(obs_freq) * (
         get_partition_function(n_items, alpha_old, cardinalities, logz_estimate, metric) -
           get_partition_function(n_items, alpha_proposal, cardinalities, logz_estimate, metric)
     ) + std::log(alpha_proposal) - std::log(alpha_old);
 
   // Draw a uniform random number
-  double u = std::log(arma::randu<double>());
+  double u = std::log(randu<double>());
 
   if(ratio > u && alpha_proposal < alpha_max){
     ++alpha_acceptance(cluster_index);
@@ -65,23 +68,22 @@ double update_alpha(arma::vec& alpha_acceptance,
 }
 
 
-void update_rho(arma::cube& rho, arma::vec& rho_acceptance, arma::mat& rho_old,
+void update_rho(cube& rho, vec& rho_acceptance, mat& rho_old,
                 int& rho_index, const int& cluster_index, const int& rho_thinning,
-                const double& alpha_old, const int& leap_size, const arma::mat& rankings,
+                const double& alpha_old, const int& leap_size, const mat& rankings,
                 const std::string& metric, const int& n_items, const int& t,
-                const arma::uvec& element_indices, const arma::vec& obs_freq) {
+                const uvec& element_indices, const vec& obs_freq) {
 
-  arma::vec rho_cluster = rho_old.col(cluster_index);
+  vec rho_cluster = rho_old.col(cluster_index);
 
   // Sample a rank proposal
-  arma::vec rho_proposal;
-  arma::uvec indices;
+  vec rho_proposal;
+  uvec indices;
   double prob_backward, prob_forward;
 
   leap_and_shift(rho_proposal, indices, prob_backward, prob_forward,
                  rho_cluster, leap_size, !((metric == "cayley") || (metric == "ulam")));
 
-
   // Compute the distances to current and proposed ranks
   double dist_new = rank_dist_sum(rankings.rows(indices), rho_proposal(indices), metric, obs_freq);
   double dist_old = rank_dist_sum(rankings.rows(indices), rho_cluster(indices), metric, obs_freq);
@@ -91,7 +93,7 @@ void update_rho(arma::cube& rho, arma::vec& rho_acceptance, arma::mat& rho_old,
     std::log(prob_backward) - std::log(prob_forward);
 
   // Draw a uniform random number
-  double u = std::log(arma::randu<double>());
+  double u = std::log(randu<double>());
 
   if(ratio > u){
     rho_old.col(cluster_index) = rho_proposal;
