@@ -1,11 +1,13 @@
-#include "RcppArmadillo.h"
+#include <RcppArmadillo.h>
 #include "smc.h"
-#include <cmath>
+#include "leapandshift.h"
+
+using namespace arma;
 
 // [[Rcpp::depends(RcppArmadillo)]]
 //' @title Metropolis-Hastings Rho
 //' @description Function to perform Metropolis-Hastings for new rho under the Mallows model with footrule distance metric!
-//' @inheritParams get_mallows_loglik
+//' @inheritParams get_exponent_sum
 //' @param leap_size Integer specifying the step size of the leap-and-shift
 //' proposal distribution.
 //' @export
@@ -49,24 +51,24 @@ arma::vec metropolis_hastings_rho(
 	const int leap_size
 ) {
   // create new potential consensus ranking
-  const Rcpp::List kernel = leap_and_shift_probs(rho, leap_size, n_items);
-
-  // output from leap-and-shift is of the following
-  const arma::vec& rho_prime = Rcpp::as<arma::vec>(kernel["rho_prime"]);
-  const double& forwards_prob = Rcpp::as<double>(kernel["forwards_prob"]); // rho_prime|rho
-  const double& backwards_prob = Rcpp::as<double>(kernel["backwards_prob"]); // rho|rho_prime
+  vec rho_proposal{};
+  uvec indices{};
+  double prob_forward, prob_backward;
+  leap_and_shift(rho_proposal, indices, prob_backward, prob_forward,
+                 rho, leap_size, false);
 
   // evaluate the log-likelihood with current rankings
-  const double mallows_loglik_curr = get_mallows_loglik(alpha, rho, n_items, rankings, metric);
-  const double mallows_loglik_prop = get_mallows_loglik(alpha, rho_prime, n_items, rankings, metric);
+  const double mallows_loglik_curr = get_exponent_sum(alpha, rho, n_items, rankings, metric);
+  const double mallows_loglik_prop = get_exponent_sum(alpha, rho_proposal, n_items, rankings, metric);
 
   // calculate acceptance probability
-  const double& loga = std::log(backwards_prob) - std::log(forwards_prob) + mallows_loglik_prop - mallows_loglik_curr;
+  const double& loga = std::log(prob_backward) - std::log(prob_forward) +
+    mallows_loglik_prop - mallows_loglik_curr;
 
   // determine whether to accept or reject proposed rho and return now consensus ranking
-  const double& p = Rcpp::as<double>(Rcpp::runif(1, 0, 1));
+  const double& p = R::runif(0, 1);
   if (std::log(p) <= loga) {
-    return(rho_prime);
+    return(rho_proposal);
   } else {
     return(rho);
   }
